Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ErrMissingField = errors.New("expression references missing field")
)
var ErrNotStruct = errors.New("provided type is not a struct. only structs are supported")
Functions ¶
This section is empty.
Types ¶
type TMPL ¶
type TMPL[T any] struct { // contains filtered or unexported fields }
TMPL holds a reference to the underlying templating engine struct. It can be redered with the appropriate parameter `T`.
Click to show internal directories.
Click to hide internal directories.